--[[
Copyright (C) 2016  Neemys

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

See <LICENSE.txt> for a copy of this license, or see <http://www.gnu.org/licenses/>
]]


require("config")
require("misc")


-- In case a recipe is activated midgame and the research is already done, seek where the recipe is unlocked, check if the research is done and unlock the recipe. This function is ressource heavy, shouldn't be called often. 
-- Can be used for hidden the recipe if the recipe have been deactivated in config.

script.on_event("bptweaks-reload-recipe", function(event)
	local function inEffect(recipeName,effectsArray)
		for _,effect in pairs(effectsArray) do
			if effect['type'] == "unlock-recipe" and effect['recipe'] == recipeName then
				return true
			end
		end
		return false
	end
	for _,force in pairs(game.forces) do
		--Check Oil barreling machine
		if force.recipes[buildingplatformtweaks.oilBarrelingRecipeName] then -- only if the recipe exist
			if(buildingplatformtweaks.config.oilBarrelingBuilding) then 
				local technologyFound = false
				local recipeToUnlocked = false
				--check for building platform default config
				if(force.technologies[buildingplatformtweaks.oilBarrelingTechUnlock] and inEffect(buildingplatformtweaks.oilBarrelingRecipeName,force.technologies[buildingplatformtweaks.oilBarrelingTechUnlock].effects)) then
					technologyFound = true
					if force.technologies[buildingplatformtweaks.oilBarrelingTechUnlock].researched then
						recipeToUnlocked = true
					end
				end
				--if not in default config, search where it has been put
				if not technologyFound then
					for _,tech in pairs(force.technologies) do
						if inEffect(buildingplatformtweaks.oilBarrelingRecipeName,tech.effects) then
							technologyFound = true
							if tech.researched then
								recipeToUnlocked = true
								break --stop the loop only if the recipe is to be unlocked, if not, maybe another tech that unlock the platform is researched
							end
						end
					end
				end
				if recipeToUnlocked then
					force.recipes[buildingplatformtweaks.oilBarrelingRecipeName].enabled = true
				end
			else --no craftable 
				force.recipes[buildingplatformtweaks.oilBarrelingRecipeName].enabled = false --in case someone want to deactivate the recipe²²
			end
		end
		--check water/lub barrel
		if force.recipes[buildingplatformtweaks.waterBarrelFillRecipeName] then -- only if the recipe exist
			if(buildingplatformtweaks.config.moreBarrelRecipe) then 
				local technologyFound = false
				local recipeToUnlocked = false
				--check for building platform default config
				if(force.technologies[buildingplatformtweaks.waterLubricantTechUnlock] and inEffect(buildingplatformtweaks.waterBarrelFillRecipeName,force.technologies[buildingplatformtweaks.waterLubricantTechUnlock].effects)) then
					technologyFound = true
					if force.technologies[buildingplatformtweaks.waterLubricantTechUnlock].researched then
						recipeToUnlocked = true
					end
				end
				--if not in default config, search where it has been put
				if not technologyFound then
					for _,tech in pairs(force.technologies) do
						if inEffect(buildingplatformtweaks.waterBarrelFillRecipeName,tech.effects) then
							technologyFound = true
							if tech.researched then
								recipeToUnlocked = true
								break --stop the loop only if the recipe is to be unlocked, if not, maybe another tech that unlock the platform is researched
							end
						end
					end
				end
				if recipeToUnlocked then
					force.recipes[buildingplatformtweaks.waterBarrelFillRecipeName].enabled = true
					force.recipes[buildingplatformtweaks.lubricantBarrelFillRecipeName].enabled = true
					force.recipes[buildingplatformtweaks.waterBarrelEmptyRecipeName].enabled = true
					force.recipes[buildingplatformtweaks.lubricantBarrelEmptyRecipeName].enabled = true
				end
			else --no craftable 
				force.recipes[buildingplatformtweaks.waterBarrelFillRecipeName].enabled = false
				force.recipes[buildingplatformtweaks.lubricantBarrelFillRecipeName].enabled = false
				force.recipes[buildingplatformtweaks.waterBarrelEmptyRecipeName].enabled = false
				force.recipes[buildingplatformtweaks.lubricantBarrelEmptyRecipeName].enabled = false
			end
		end
	end
end)

