--[[
Copyright (C) 2016  Neemys

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

See <LICENSE.txt> for a copy of this license, or see <http://www.gnu.org/licenses/>
]]

log(buildingplatform.config.craftable)

if(buildingplatformtweaks.config.moreBarrelRecipe) then 

	local waterBarrelName = "bp-water-barrel"
	local waterBarrelIcon = buildingplatformtweaks.modRoot.."/graphics/more_barrel/water-barrel.png"
	local waterBarrelOrder = "c[bp-water-barrel]-a"
	local fillWaterRecipeName = buildingplatformtweaks.waterBarrelFillRecipeName
	local fillWaterRecipeIcon = buildingplatformtweaks.modRoot.."/graphics/more_barrel/fill-water-barrel.png"
	local fillWaterRecipeResults={{type="item", name=waterBarrelName, amount=1}}
	local fillWaterRecipeOrder = "c[bp-empty-water-barrel]-a"
	local emptyWaterRecipeName = buildingplatformtweaks.waterBarrelEmptyRecipeName
	local emptyWaterRecipeIcon = buildingplatformtweaks.modRoot.."/graphics/more_barrel/empty-water-barrel.png"
	local emptyWaterRecipeOrder = "d[bp-empty-water-barrel]-a"
	local emptyWaterRecipeIngredients={{type="item", name=waterBarrelName, amount=1}}
	local waterLiquidName = "water"
	local craftWaterEnergyRequired = 0.5
	local craftWaterAmountPerBarrel = 24

	
	local lubricantBarrelName = "bp-lubricant-barrel"
	local lubricantBarrelIcon = buildingplatformtweaks.modRoot.."/graphics/more_barrel/lubricant-barrel.png"
	local lubricantBarrelOrder = "c[bp-lubricant-barrel]-b"
	local fillLubricantRecipeName = buildingplatformtweaks.lubricantBarrelFillRecipeName
	local fillLubricantRecipeIcon = buildingplatformtweaks.modRoot.."/graphics/more_barrel/fill-lubricant-barrel.png"
	local fillLubricantRecipeResults={{type="item", name=lubricantBarrelName, amount=1}}
	local fillLubricantRecipeOrder = "c[bp-empty-lubricant-barrel]-b"
	local emptyLubricantRecipeName = buildingplatformtweaks.lubricantBarrelEmptyRecipeName
	local emptyLubricantRecipeIcon = buildingplatformtweaks.modRoot.."/graphics/more_barrel/empty-lubricant-barrel.png"
	local emptyLubricantRecipeOrder = "d[bp-empty-lubricant-barrel]-b"
	local emptyLubricantRecipeIngredients={{type="item", name=lubricantBarrelName, amount=1}}
	local lubricantLiquidName = "lubricant"

	
	--We copy vanilla recipe and item if they exist to have one that behave the same (ie a mod change the stack size, it's reflected in our item as well)
	
	local waterBarrel
	local lubricantBarrel
	if(data.raw["item"]["crude-oil-barrel"]) then
		waterBarrel = util.table.deepcopy(data.raw["item"]["crude-oil-barrel"])
		waterBarrel.name = waterBarrelName
		waterBarrel.icon = waterBarrelIcon
		waterBarrel.order = waterBarrelOrder
		
		lubricantBarrel = util.table.deepcopy(data.raw["item"]["crude-oil-barrel"])
		lubricantBarrel.name = lubricantBarrelName
		lubricantBarrel.icon = lubricantBarrelIcon
		lubricantBarrel.order = lubricantBarrelOrder
	else
		waterBarrel = 
		{
			type = "item",
			name = waterBarrelName,
			icon = waterBarrelIcon,
			flags = {"goes-to-main-inventory"},
			subgroup = "barrel",
			order = waterBarrelOrder,
			stack_size = 10
		}
		
		lubricantBarrel = 
		{
			type = "item",
			name = lubricantBarrelName,
			icon = lubricantBarrelIcon,
			flags = {"goes-to-main-inventory"},
			subgroup = "barrel",
			order = lubricantBarrelOrder,
			stack_size = 10
		}
	end
	
	
	local fillWaterRecipe = nil
	local fillLubricantRecipe = nil
	if(data.raw["recipe"]["fill-crude-oil-barrel"]) then
		fillWaterRecipe	= util.table.deepcopy(data.raw["recipe"]["fill-crude-oil-barrel"])
		fillWaterRecipe.name = fillWaterRecipeName
		fillWaterRecipe.energy_required = craftWaterEnergyRequired
		fillWaterRecipe.icon = fillWaterRecipeIcon
		for key,item in pairs(fillWaterRecipe.ingredients) do
			if(fillWaterRecipe.ingredients[key].name == "crude-oil") then
				fillWaterRecipe.ingredients[key].name = waterLiquidName
				fillWaterRecipe.ingredients[key].amount = craftWaterAmountPerBarrel
			end
		end
		fillWaterRecipe.results = fillWaterRecipeResults
		fillWaterRecipe.order = "c[bp-empty-water-barrel]-a"
		
		fillLubricantRecipe	= util.table.deepcopy(data.raw["recipe"]["fill-crude-oil-barrel"])
		fillLubricantRecipe.name = fillLubricantRecipeName
		fillLubricantRecipe.icon = fillLubricantRecipeIcon
		for key,item in pairs(fillLubricantRecipe.ingredients) do
			if(fillLubricantRecipe.ingredients[key].name == "crude-oil") then
				fillLubricantRecipe.ingredients[key].name = lubricantLiquidName
			end
		end
		fillLubricantRecipe.results = fillLubricantRecipeResults
		fillLubricantRecipe.order = "c[bp-empty-lubricant-barrel]-a"
	else
		fillWaterRecipe = {
			type = "recipe",
			name = fillWaterRecipeName,
			category = "crafting-with-fluid",
			energy_required = craftWaterEnergyRequired,
			subgroup = "barrel",
			order = "b[fill-crude-oil-barrel]",
			enabled = false,
			icon = fillWaterRecipeIcon,
			ingredients =
			{
			  {type="fluid", name=waterLiquidName, amount=craftWaterAmountPerBarrel},
			  {type="item", name="empty-barrel", amount=1},
			},
			results=fillWaterRecipeResults
		}
		
		fillLubricantRecipe = {
			type = "recipe",
			name = fillLubricantRecipeName,
			category = "crafting-with-fluid",
			energy_required = 1,
			subgroup = "barrel",
			order = "b[fill-crude-oil-barrel]",
			enabled = false,
			icon = fillLubricantRecipeIcon,
			ingredients =
			{
			  {type="fluid", name=lubricantLiquidName, amount=25},
			  {type="item", name="empty-barrel", amount=1},
			},
			results=fillLubricantRecipeResults
		}
	end
	
	local emptyWaterRecipe = nil
	local emptyLubricantRecipe = nil
	if(data.raw["recipe"]["empty-crude-oil-barrel"]) then
		emptyWaterRecipe = util.table.deepcopy(data.raw["recipe"]["empty-crude-oil-barrel"])
		emptyWaterRecipe.name = emptyWaterRecipeName
		emptyWaterRecipe.energy_required = craftWaterEnergyRequired
		emptyWaterRecipe.icon = emptyWaterRecipeIcon
		emptyWaterRecipe.ingredients = emptyWaterRecipeIngredients
		for key,item in pairs(emptyWaterRecipe.results) do
			if(emptyWaterRecipe.results[key].name == "crude-oil") then
				emptyWaterRecipe.results[key].name = waterLiquidName
				emptyWaterRecipe.results[key].amount = craftWaterAmountPerBarrel
			end
		end
		emptyWaterRecipe.order = emptyWaterRecipeOrder
		
		emptyLubricantRecipe = util.table.deepcopy(data.raw["recipe"]["empty-crude-oil-barrel"])
		emptyLubricantRecipe.name = emptyLubricantRecipeName
		emptyLubricantRecipe.icon = emptyLubricantRecipeIcon
		emptyLubricantRecipe.ingredients = emptyLubricantRecipeIngredients
		for key,item in pairs(emptyLubricantRecipe.results) do
			if(emptyLubricantRecipe.results[key].name == "crude-oil") then
				emptyLubricantRecipe.results[key].name = lubricantLiquidName
			end
		end
		emptyLubricantRecipe.order = emptyLubricantRecipeOrder
	else
		emptyWaterRecipe = {
			type = "recipe",
			name = emptyWaterRecipeName,
			category = "crafting-with-fluid",
			energy_required = craftWaterEnergyRequired,
			subgroup = "barrel",
			order = emptyWaterRecipeOrder,
			enabled = false,
			icon = emptyWaterRecipeIcon,
			ingredients =emptyWaterRecipeIngredients,
			results=
			{
			  {type="fluid", name=waterLiquidName, amount=craftWaterAmountPerBarrel},
			  {type="item", name="empty-barrel", amount=1}
			}
		}
		
		emptyLubricantRecipe = {
			type = "recipe",
			name = emptyLubricantRecipeName,
			category = "crafting-with-fluid",
			energy_required = 1,
			subgroup = "barrel",
			order = emptyLubricantRecipeOrder,
			enabled = false,
			icon = emptyLubricantRecipeIcon,
			ingredients =emptyLubricantRecipeIngredients,
			results=
			{
			  {type="fluid", name=lubricantLiquidName, amount=25},
			  {type="item", name="empty-barrel", amount=1}
			}
		}
	end
	
	
	--[[As other mod can add their own recipes for lubricant barrel, do not add our if they already exist :
	if(not data.raw.recipe['fill-lubricant-barrel']) then
		--fillLubricantRecipe = {}
		data:extend({fillLubricantRecipe})
	end
	if(not data.raw.recipe['empty-lubricant-barrel']) then
		--emptyLubricantRecipe = {}
		data:extend({emptyLubricantRecipe})
	end]]
	--we still add water barrel recipes as they are specially made to fill 10 steam engines
	
	data:extend({waterBarrel,fillWaterRecipe,emptyWaterRecipe,lubricantBarrel,fillLubricantRecipe,emptyLubricantRecipe})
	
	
	if(data.raw['technology'][buildingplatformtweaks.waterLubricantTechUnlock]) then
		table.insert(data.raw['technology'][buildingplatformtweaks.waterLubricantTechUnlock].effects,
		{
			type = "unlock-recipe",
			recipe = emptyWaterRecipeName
		})
		table.insert(data.raw['technology'][buildingplatformtweaks.waterLubricantTechUnlock].effects,
		{
			type = "unlock-recipe",
			recipe = emptyLubricantRecipeName
		})
		table.insert(data.raw['technology'][buildingplatformtweaks.waterLubricantTechUnlock].effects,
		{
			type = "unlock-recipe",
			recipe = fillWaterRecipeName
		})
		table.insert(data.raw['technology'][buildingplatformtweaks.waterLubricantTechUnlock].effects,
		{
			type = "unlock-recipe",
			recipe = fillLubricantRecipeName
		})
	else
		data.raw['recipe'][emptyWaterRecipeName].enabled = true
		data.raw['recipe'][emptyLubricantRecipeName].enabled = true
		data.raw['recipe'][fillWaterRecipeName].enabled = true
		data.raw['recipe'][fillLubricantRecipeName].enabled = true
	end
end
